@@ -2,10 +2,7 @@
 
 from .aggregate_operations import AggregateNode
 from .natural_language_filter import NaturalLanguageFilterNode
-from .schema_nodes import (
-    MigrationNode,
-    SchemaModificationNode,
-)
+from .schema_nodes import MigrationNode, SchemaModificationNode
 from .smart_operations import SmartMergeNode
 from .transaction_nodes import (
     TransactionCommitNode,
